@@ -53,7 +53,7 @@ class AdminProvider(ReboticsBaseProvider):
         self.headers['x-retailer-id'] = retailer_id
         self.headers['x-retailer-secret-key'] = retailer_secret_key
 
-    @remote_service('/api/token-auth/')
+    @remote_service('/api/token-auth/', raw=True)
     def token_auth(self, username, password, verification_code=None, **kwargs):
         payload = {
             'username': username,
@@ -63,9 +63,9 @@ class AdminProvider(ReboticsBaseProvider):
         if verification_code is not None:
             payload['verification_code'] = verification_code
 
-        json_data = self.session.post(data=payload)
-        self.set_token(json_data['token'])
-        return json_data
+        response = self.session.post(data=payload)
+        self.set_token(response.json()['token'])
+        return response
 
     def get_configurations(self, codename=None):
         """
