@@ -16,14 +16,17 @@ class RetailerProvider(ReboticsBaseProvider):
     def version(self, *kwargs):
         return self.session.get()
 
-    @remote_service('/api/v4/token-auth/')
+    @remote_service('/api/v4/token-auth/', raw=True)
     def token_auth(self, username, password, **kwargs):
-        json_data = self.session.post(data={
-            'username': username,
-            'password': password
-        })
-        self.set_token(json_data['token'])
-        return json_data
+        payload = dict(
+            username=username,
+            password=password,
+        )
+        if 'verification_code' in kwargs.keys():
+            payload['verification_code'] = kwargs['verification_code']
+        response = self.session.post(json=payload)
+        self.set_token(response.json()['token'])
+        return response
 
     def api_login(self, username, password):
         return self.token_auth(username, password)
